@@ -3,9 +3,5 @@ pub use auto_concretize::enabled as auto_concretize_enabled;
 
 pub mod dirs;
 
-pub mod examples;
-
 mod serde_format;
 pub use serde_format::*;
-
-pub mod testing;
